@@ -61,7 +61,7 @@ class TestAuditApi(base.TestCase):
 
     def test_get_list(self):
         req = self.api_request('GET', 'http://host:8774/v2/public/servers')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'list')
         self.assertEqual(payload['typeURI'],
                          'http://schemas.dmtf.org/cloud/audit/1.0/event')
@@ -91,14 +91,14 @@ class TestAuditApi(base.TestCase):
         req = self.api_request('GET',
                                'http://host:8774/v2/public/servers/' +
                                str(uuid.uuid4()))
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'read')
         self.assertEqual(payload['outcome'], 'pending')
 
     def test_get_unknown_endpoint(self):
         req = self.api_request('GET',
                                'http://unknown:8774/v2/public/servers/')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'list')
         self.assertEqual(payload['outcome'], 'pending')
         self.assertEqual(payload['target']['name'], 'unknown')
@@ -107,19 +107,19 @@ class TestAuditApi(base.TestCase):
 
     def test_put(self):
         req = self.api_request('PUT', 'http://host:8774/v2/public/servers')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'update')
         self.assertEqual(payload['outcome'], 'pending')
 
     def test_delete(self):
         req = self.api_request('DELETE', 'http://host:8774/v2/public/servers')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'delete')
         self.assertEqual(payload['outcome'], 'pending')
 
     def test_head(self):
         req = self.api_request('HEAD', 'http://host:8774/v2/public/servers')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'read')
         self.assertEqual(payload['outcome'], 'pending')
 
@@ -127,13 +127,13 @@ class TestAuditApi(base.TestCase):
         req = self.api_request('POST',
                                'http://host:8774/v2/public/servers/' +
                                str(uuid.uuid4()))
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'update')
         self.assertEqual(payload['outcome'], 'pending')
 
     def test_post_create(self):
         req = self.api_request('POST', 'http://host:8774/v2/public/servers')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'create')
         self.assertEqual(payload['outcome'], 'pending')
 
@@ -144,15 +144,15 @@ class TestAuditApi(base.TestCase):
         req.body = '{"createImage" : {"name" : "new-image","metadata": ' \
                    '{"ImageType": "Gold","ImageVersion": "2.0"}}}'
         self.audit_api.append_audit_event(req)
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['action'], 'create')
         self.assertEqual(payload['outcome'], 'pending')
 
     def test_response_mod_msg(self):
         req = self.api_request('GET', 'http://host:8774/v2/public/servers')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.audit_api.mod_audit_event(req, webob.Response())
-        payload2 = req.environ['cadf_event']
+        payload2 = req.environ['CADF_EVENT']
         self.assertEqual(payload['id'], payload2['id'])
         self.assertEqual(payload['tags'], payload2['tags'])
         self.assertEqual(payload2['outcome'], 'success')
@@ -164,9 +164,9 @@ class TestAuditApi(base.TestCase):
 
     def test_no_response(self):
         req = self.api_request('GET', 'http://host:8774/v2/public/servers')
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.audit_api.mod_audit_event(req, None)
-        payload2 = req.environ['cadf_event']
+        payload2 = req.environ['CADF_EVENT']
         self.assertEqual(payload['id'], payload2['id'])
         self.assertEqual(payload['tags'], payload2['tags'])
         self.assertEqual(payload2['outcome'], 'unknown')
@@ -179,11 +179,11 @@ class TestAuditApi(base.TestCase):
         self.ENV_HEADERS['REQUEST_METHOD'] = 'GET'
         req = webob.Request.blank('http://host:8774/v2/public/servers',
                                   environ=self.ENV_HEADERS)
-        self.assertNotIn('cadf_event', req.environ)
+        self.assertNotIn('CADF_EVENT', req.environ)
         self.audit_api.mod_audit_event(req, webob.Response())
-        self.assertIn('cadf_event', req.environ)
+        self.assertIn('CADF_EVENT', req.environ)
         self.assertIn('CADF_EVENT_CORRELATION_ID', req.environ)
-        payload = req.environ['cadf_event']
+        payload = req.environ['CADF_EVENT']
         self.assertEqual(payload['outcome'], 'success')
         self.assertEqual(payload['reason']['reasonType'], 'HTTP')
         self.assertEqual(payload['reason']['reasonCode'], '200')
